                      function dtpc
% *****************************************************************
%                     P r o g r a m    DTPC
% *****************************************************************
%
%  PURPOSE:
%     Resolve numerically differential equations of plane motion 
%     of a particle in polar coordinates
%          m*(rtt-r*ft^2)    = Fr(t,r,f,rt,ft,rtt,ftt),
%          m*(r*ftt+2*rt*ft) = Ff(t,r,f,rt,rt,rtt,ftt)
%     plots trajectory and graphics of coordinates and velocity.
%
%  INPUT DATA:
%     m    - mass of the body ;
%     Fr   - sum of projections of forces on axis [r] ;
%     Ff   - sum of projections of forces on axis [f] ;
%     r0   - initial value of the coordinate r ;
%     f0   - initial value of the coordinate f ;
%     v0   - initial value of velocity ;
%     alfa - angle between v0 and polar axis p;
%     Tend - upper bound of the integration ;
%     eps  - precision of the integration ;
%     np   - number of parameters .
%     P{1}, P{2}, ..., P{np} - names of the parameters (array of cells);
%
%  NOTES:
%   1. The coordinates are designed by the symbols 'r'- radius, 
%      'f'-polar angle. There first derivatives by 'rt', 'ft' and 
%      second by 'rtt', 'ftt';
%   2. If the second derivatives of the coordinates are present in the 
%      right sides of DE's, the problem can be solved only if 'rtt' and
%      'ftt' are present linearly!
%   3. The physical names of the parameters are assigned to the
%      cells of the array P like this: P{1}='m', P{2}='c',...;
%   4. All the data can be input from file or in interactive mode.
%   5. Even the most sample problems can't be solved analitically
%      in polar coordinates!
% 
%  EXAMPLE of DATA FILE:
% % Dynamics of a particle, moving
% % on a horizontal plane under action 
% % of an elastic and an resistance force.
%   m    =  'm';
%   Fr   = '-c*r - k*rt';
%   Ff   = '-k*r*ft';
%   r0   = 'r0';
%   f0   = 'f0';
%   v0   = 'v0';
%   alfa = 'alfa';
%   Tend = 20;
%   eps  = 1.e-8;
%   np   = 3;
%   P{1} = 'm';
%   P{2} = 'c';
%   P{3} = 'k';