                     function dtx
% ***************************************************************
%                    P r o g r a m   DTX
% ***************************************************************
%
%  PURPOSE:
%     Resolve numerically differential equation of rectilinear motion
%     of a particle
%                      m*d2x/dt2 = Fx(t,x,v)
%     and plots graphics of coordinate, velocity and phase plane.
%     If possible, the program could solve the problem analytically.
%
%  INPUT DATA:
%     m    - mass of the particle;
%     Fx   - projection of forces on axis x - Fx = Fx(t,x,v);
%     x0   - initial value of the coordinate ;
%     v0   - initial value of the velocity ;
%     Tend - upper bound of the integration ;
%     eps  - precision of the integration ;
%     np   - number of parameters .
%     P{1}, P{2}, ..., P{np} - names of the parameters (array of cells);
%
%  NOTES:
%   1. The coordinate is designed by the symbol 'x' and velocity by 'v';
%   2. The physical names of the parameters are assigned to the
%      cells of the array P like this: P{1}='m', P{2}='c',...;
%   3. For analytical solution the values of Tend, eps, np and P are not
%      needed;
%   4. Initial values x0, v0 have to be entered as strings, even though
%      they represent numbers!
%   5. All the data can be input from file or in interactive mode.
% 
%  EXAMPLE of DATA FILE:
%   % Data for problem ...
%     m    = 'm';  ( or m = '5.3';)
%     Fx   = '-k*v - c*x'; % k, c - parameters
%     x0   = 'x0'; ( or x0 = '0.1';)
%     v0   = 'v0'; ( or v0 = '10';)
%     Tend = 20;
%     eps  = 1.e-8;
%     np   = 3;
%     P{1} = 'm';
%     P{2} = 'k';
%     P{3} = 'c';