                      function dtxy
% *****************************************************************
%                     P r o g r a m    DTXY
% *****************************************************************
%
%  PURPOSE:
%     Resolve numerically differential equations of plane motion 
%     of a particle   m*d2x/dt2 = Fx(t,x,y,xt,yt);
%                     m*d2y/dt2 = Fy(t,x,y,xt,yt),
%     plots trajectory and graphics of coordinates and velocity.
%     If possible, the program could solve the problem analytically.
%
%  INPUT DATA:
%     m    - mass of the body ;
%     Fx   - sum of projections of forces on axis x ;
%     Fy   - sum of projections of forces on axis y ;
%     x0   - initial value of the coordinate x ;
%     y0   - initial value of the coordinate y ;
%     v0   - initial value of velocity ;
%     alfa - angle between v0 and horizontal plane;
%     Tend - upper bound of the integration ;
%     eps  - precision of the integration ;
%     np   - number of parameters .
%     P{1}, P{2}, ..., P{np} - names of the parameters (array of cells);
%
%  NOTES:
%   1. The coordinates are designed by the symbols 'x', 'y'
%      and there first derivatives by 'xt', 'yt';
%   2. The physical names of the parameters are assigned to the
%      cells of the array P like this: P{1}='m', P{2}='c',...;
%   3. For analytical solution the values of Tend, eps, np and P are not
%      needed.
%   4. Initial values x0, y0, v0, alfa must to be entered as strings, 
%      even though they represent numbers!
%   5. All the data can be input from file or in interactive mode.
% 
%  EXAMPLE of DATA FILE:
% % Dynamics of a projectile, lanched
% % with initial velocity v0 under 
% % angle "alfa'
%   m    =  'm';
%   Fx   = '-k*xt';
%   Fy   = '-k*yt - m*9.81';
%   x0   = '0';
%   y0   = '0';
%   v0   = 'v0';
%   alfa = 'alfa';
%   Tend = 10;
%   eps  = 1.e-10;
%   np   = 2;
%   P{1} = 'm';
%   P{2} = 'k';